""" 
file: positionMatch.py
 
Description:
    This tool switches the polevector spaces keeping their position.
 
How to Run: 

from rigitAnimTools import positionMatch
reload(positionMatch)
positionMatch.toolUI()
"""

import maya.cmds as mc

selectionList = None
objectsTextField = None


def toolUI():
    
    """
    build tool UI
    """
    
    global objectsTextField
    
    window = 'PositionMatch'
    windowObj = 'positionMatch'
    if (mc.window(windowObj, exists = True)):
        
        mc.deleteUI(windowObj)
        

    window = mc.window(windowObj, title = "RIG-IT positionMatch v1.0.1", widthHeight = (300, 300),
                            maximizeButton = True, resizeToFitChildren = True)
    mc.columnLayout()
    mc.text('   Select objects to keep their position   ', h = 30)
    mc.separator()
    mc.setParent('..')
    
    mc.rowColumnLayout(numberOfColumns = 2, columnWidth = [(1, 50), (2, 200)])    
    mc.text('-->')
    # mc.columnLayout(columnWidth = 200)
    mc.button(l = 'Get Objects', c = getObjectsSelection)
    mc.text(' ')
    tx = mc.textField(tx = '', enable = False)
    objectsTextField = tx
    mc.setParent('..')
    
    mc.rowColumnLayout(numberOfColumns = 2, columnWidth = [(1, 50), (2, 200)])    
    mc.text('_^_')
    mc.button(l = 'Update Objects', c = updateObjectsSelection)
    mc.text(label = '...')
    mc.button(l = 'Select Objects', c = selectObjectsSelection)
    mc.setParent('..')
    
    mc.separator(h = 10, style = 'none')
    
    mc.columnLayout()
    mc.text('   Change rig pose or control space  ', h = 30)
    mc.separator()
    mc.setParent('..')
    
    mc.rowColumnLayout(numberOfColumns = 2, columnWidth = [(1, 50), (2, 200)])    
    mc.text('<--')
    mc.button(l = 'Match Objects Previous Position', c = restoreObjectsPosition)
    mc.setParent('..')
    
    mc.columnLayout()
    mc.text('')
    mc.separator(style = 'in', h = 30)
    mc.setParent('..')
    
    mc.rowColumnLayout(numberOfColumns = 2, columnWidth = [(1, 50), (2, 200)])    
    mc.text('-')
    mc.button(l = 'Clear Objects Selection Buffer', c = clearSelectionBuffer)
    mc.setParent('..')
    
    mc.columnLayout()
    mc.text(' ')
    mc.separator(style = 'in', h = 10)
    mc.setParent('..')
    
    mc.showWindow(window)
    mc.window(windowObj, e = True, w = 300, h = 180)


def getObjectsSelection(*args):
    
    """
    get selection of objects in scene
    """
    
    selection = keepSelection(restoreSel = False)
    selectionStr = ''.join(selection)
    mc.textField(objectsTextField, e = True, tx = selectionStr)
    

def updateObjectsSelection(*args):
    
    """
    get selection of objects in scene
    """
    
    keepSelection(updateData = True)

def selectObjectsSelection(*args):
    
    """
    get selection of objects in scene
    """
    
    selection = keepSelection(restoreSel = True)
    selectionObjs = list(selection.keys())
    mc.select(selectionObjs)
    
    
def restoreObjectsPosition(*args):
    
    """
    restore positions of objects
    """
    
    selection = keepSelection(restoreSel = True)
    
    if not selection:
        
        return
    
    for obj, vals in list(selection.items()):
        
        mc.xform(obj, t = vals[0], ws = True)
        mc.xform(obj, ro = vals[1], ws = True, rotateOrder = vals[2])
        
    
def clearSelectionBuffer(*args):
    
    """
    clear selection variable
    """
    
    keepSelection(clear = True)
    mc.textField(objectsTextField, e = True, tx = '')
    

def keepSelection(restoreSel = False, clear = False, updateData = False):
    
    """
    keep scene selection and their transform data
    """
    
    global selectionList
    
    if restoreSel:
        
        if selectionList:
            
            return selectionList
    
    if clear:
        
        selectionList = None
        return
    
    # get new selection data
    selectedObjs = mc.ls(sl = 1, type = 'transform')
    
    if not selectedObjs:
        
        return
    
    if updateData and selectionList:
        
        selectedObjs = selectionList
    
    selectionList = {}
    for obj in selectedObjs:
        
        translateList = mc.xform(obj, q = 1, t = True, ws = True)
        rotateList = mc.xform(obj, q = 1, ro = True, ws = True)
        rotateOrder = mc.xform(obj, q = 1, rotateOrder = True)
        selectionList[obj] = [translateList, rotateList, rotateOrder]
    
    return selectionList




