# -----------------------------------------------
# rigitAnimTools
#
# set of tools for animators using RIG-IT rigs
#
# copyright www.rig-it.net
# -----------------------------------------------

import maya.cmds as mc
mayaVersion = int( mc.about( v=True ) )

from .fbxExport import fbxExportTool
from . import otherUtils
from . import positionMatch
from . import speedMeasureLoc
from .ikfkMatchTool import ikFkMatch
from .saveShadersTool import saveShaders

if mayaVersion > 2020:
    from .softmodSculpt_p3 import v1_0 as softmodSculpt
else:
    from .softmodSculpt_p2 import v1_1 as softmodSculpt


class main_window:
    
    def __init__(self):
        
        self.window = 'main_window'
        self.title = 'rigitAnimTools'
        self.size = (300,200)
        
        # check if window is already opened
        if mc.window( self.window, exists = True ):
            mc.deleteUI( self.window, window = True )
        
        # window creation
        self.window = mc.window( self.window, t = self.title, widthHeight = self.size )
        
        mc.columnLayout( adjustableColumn=True ) 

        mc.text( label='RIG-IT Anim Tools' )
        mc.text( label='' )

        mc.button( label = 'IK-FK Match', command = self.ikFkMatchUi )
        mc.button( label = 'Position Match', command = self.positionMatchUi )
        mc.button( label = 'FBX Export Tool', command = self.fbxExportToolUi )
        mc.button( label = 'Speed Measure Loc', command = self.speedMeasureLocUi )
        mc.button( label = 'SoftMod Sculpt', command = self.softmodSculptUi )
        mc.button( label = 'Save Shaders', command = self.saveShadersUi )
        mc.button( label = 'Other Utils', command = self.otherUtilsUi )

        mc.text( label='' )
        mc.text(l='<a href="https://www.rig-it.net/resources/">RIG-IT.net Resources</a>', hl=True)
        # https://www.rig-it.net/resources/?q=HTML+link

        # display window
        mc.showWindow(self.window)

    def fbxExportToolUi(self, *args):

        fbxExportTool.fbxExportUI()
    
    def positionMatchUi(self, *args):

        positionMatch.toolUI()
    
    def speedMeasureLocUi(self, *args):

        speedMeasureLoc.toolUI()
    
    def ikFkMatchUi(self, *args):

        ikFkMatch.ikFkMatchUI()
    
    def saveShadersUi(self, *args):

        saveShaders.toolUI()
    
    def softmodSculptUi(self, *args):

        softmodSculpt.run.showWin()
    
    def otherUtilsUi(self, *args):

        otherUtils.mainUI()



def mainUI():

    mainUI = main_window()
