'''
connect at rigit.utils
@category Rigging @subcategory Utils
@tags connect message
@author: jakub
'''

import maya.cmds as mc

from . import name
from . import numbers


def message( sourceObj, destObj, sourceMsgName = 'msg', destMsgName = 'msg' ):
    
    '''
    create a message connection using multi-attribute so destination can have more messages connected
    
    @param sourceObj: source object name
    @type sourceObj: str
    @param destObj: destination object name
    @type destObj: str
    @param sourceMsgName: source message attribute name
    @type sourceMsgName: str
    @param destMsgName: destination message attribute name
    @type destMsgName: str
    @return: None
    '''
    
    if not mc.objExists( sourceObj + '.' + sourceMsgName ):
        
        mc.addAttr( sourceObj, ln = sourceMsgName, at = 'message' )
    
    if not mc.objExists( destObj + '.' + destMsgName ):
        
        mc.addAttr( destObj, ln = destMsgName, at = 'message', multi = 1 )
    
    # find the next available index
    
    destMessageInds = mc.getAttr( destObj + '.' + destMsgName, mi = 1 )
    destIndex = 0
    if destMessageInds: destIndex = numbers.getNextAvailableIndex( destMessageInds )
    
    # connect message attributes
    
    srcPlug = sourceObj + '.' + sourceMsgName
    destPlug = destObj + '.' + destMsgName + '[' + str( destIndex ) + ']'
    mc.connectAttr( srcPlug, destPlug )


