'''
controlShapes at rigit.rigbase
@category Rigging @subcategory Rigbase
@tags control class
'''

import maya.cmds as mc

from . import shape

def _printControlCVsPositionsForFunction( curveObj ):
    
    """
    print control CVs positions for controlShapes function
    """
    
    cvs = mc.ls( curveObj + '.cv[*]', fl = True )
    poslist = []
    
    print 'pos = []'
    
    for cv in cvs:
        
        pos = mc.xform( cv, q = True, t = True, ws = True )
        poslist.append( pos )
        print 'pos.append( ( %f, %f, %f ) )' % ( pos[0], pos[1], pos[2] )
    
    return poslist

def circle( normal = 'x', scale = [1, 1, 1], degree = 3 ):
    
    normalD = { 'x':[1, 0, 0], 'y':[0, 1, 0], 'z':[0, 0, 1] }
    new = mc.circle( nr = normalD[normal], ch = 0, r = 1.0, d = degree )[0]
    
    shape.scale( new, scale )
    
    return new

def square( scale = [1, 1, 1], normal = [0, 1, 0] ):
    
    x = 0.5
    pos = []
    pos.append( ( x, 0, x ) )
    pos.append( ( x, 0, -x ) )
    pos.append( ( -x, 0, -x ) )
    pos.append( ( -x, 0, x ) )
    pos.append( ( x, 0, x ) )
    
    new = mc.curve( d = 1, p = pos )
    upVector = [1, 0, 0]
    
    if normal[0] > normal[1] and normal[0] > normal[2]:
        
        upVector = [0, 1, 0]
    
    refObj = mc.joint( n = 'controlShapeAimRef_jnt', p = normal )
    mc.delete( mc.aimConstraint( refObj, new, aim = [0, 1, 0], u = upVector, wu = [1, 0, 0], wut = 'scene' ) )
    mc.delete( refObj )
    mc.makeIdentity( new, a = True, r = True )
    
    shape.scale( new, scale )
    
    return new
    
def locator( scale = [1, 1, 1] ):
    
    x = 0.5
    pos = []
    pos.append( ( -x, 0, 0 ) )
    pos.append( ( x, 0, 0 ) )
    pos.append( ( 0, 0, 0 ) )
    pos.append( ( 0, 0, x ) )
    pos.append( ( 0, 0, -x ) )
    pos.append( ( 0, 0, 0 ) )
    pos.append( ( 0, x, 0 ) )
    pos.append( ( 0, -x, 0 ) )    
    
    
    new = mc.curve( d = 1, p = pos )
    shape.scale( new, scale )
    
    return new

def cube( scale = [1, 1, 1] ):

    pos = []
    pos.append( ( 0.5, -0.5, 0.5 ) )
    pos.append( ( 0.5, -0.5, -0.5 ) )
    pos.append( ( 0.5, 0.5, -0.5 ) )
    pos.append( ( -0.5, 0.5, -0.5 ) )
    pos.append( ( -0.5, 0.5, 0.5 ) )
    pos.append( ( -0.5, -0.5, 0.5 ) )
    pos.append( ( 0.5, -0.5, 0.5 ) )
    pos.append( ( 0.5, 0.5, 0.5 ) )
    pos.append( ( 0.5, 0.5, -0.5 ) )
    pos.append( ( -0.5, 0.5, -0.5 ) )
    pos.append( ( -0.5, -0.5, -0.5 ) )
    pos.append( ( -0.5, -0.5, 0.5 ) )
    pos.append( ( -0.5, 0.5, 0.5 ) )
    pos.append( ( 0.5, 0.5, 0.5 ) )
    pos.append( ( 0.5, 0.5, -0.5 ) )
    pos.append( ( 0.5, -0.5, -0.5 ) )
    pos.append( ( -0.5, -0.5, -0.5 ) )
    
    new = mc.curve( d = 1, p = pos )
    shape.scale( new, scale )
    
    return new

def rtriangle( scale = [1, 1, 1] ):
    
    pos = []
    pos.append( ( 0, 0, 0 ) )
    pos.append( ( -0.5, 0, 0 ) )
    pos.append( ( 0, 0.5, 0 ) )
    pos.append( ( 0, 0, 0 ) )
    
    new = mc.curve( d = 1, p = pos )
    shape.scale( new, scale )
    
    return new
    
def triangle( scale = [1, 1, 1] ):
    
    pos = []
    pos.append( ( 0.5, 0, 0 ) )
    pos.append( ( -0.5, 0, 0 ) )
    pos.append( ( 0, 1, 0 ) )
    pos.append( ( 0.5, 0, 0 ) )
    
    new = mc.curve( d = 1, p = pos )
    shape.scale( new, scale )
    
    return new
    
def v( scale = [1, 1, 1] ):
    
    pos = []
    pos.append( ( -0.198760, -0.499778, 0.000000 ) )
    pos.append( ( -0.487601, 0.499105, 0.000000 ) )
    pos.append( ( -0.243800, 0.499105, 0.000000 ) )
    pos.append( ( 0.000000, -0.165984, 0.000000 ) )
    pos.append( ( 0.243800, 0.499105, -0.000000 ) )
    pos.append( ( 0.487601, 0.499105, -0.000000 ) )
    pos.append( ( 0.198760, -0.499778, -0.000000 ) )
    pos.append( ( -0.198760, -0.499778, 0.000000 ) )
    
    new = mc.curve( d = 1, p = pos )
    shape.scale( new, scale )
    
    return new
    

def t( scale = [1, 1, 1] ):
    
    pos = []
    pos.append( ( -0.187652, -0.499778, 0.000000 ) )
    pos.append( ( -0.187652, 0.087069, 0.000000 ) )
    pos.append( ( -0.487601, 0.087069, 0.000000 ) )
    pos.append( ( -0.487601, 0.499105, 0.000000 ) )
    pos.append( ( 0.487601, 0.499105, -0.000000 ) )
    pos.append( ( 0.487601, 0.087069, -0.000000 ) )
    pos.append( ( 0.187652, 0.087069, -0.000000 ) )
    pos.append( ( 0.187652, -0.499778, -0.000000 ) )
    pos.append( ( -0.187652, -0.499778, 0.000000 ) )

    
    new = mc.curve( d = 1, p = pos )
    shape.scale( new, scale )
    
    return new


def s( scale = [1, 1, 1] ):
    
    pos = []
    pos.append( ( 0.496615, 0.493503, 0.000000 ) )
    pos.append( ( 0.480433, 0.493503, 0.000000 ) )
    pos.append( ( -0.329002, 0.493503, 0.000000 ) )
    pos.append( ( -0.357286, 0.493503, 0.000000 ) )
    pos.append( ( -0.493503, 0.329002, 0.000000 ) )
    pos.append( ( -0.493503, 0.000000, 0.000000 ) )
    pos.append( ( -0.347964, -0.111657, 0.000000 ) )
    pos.append( ( -0.319999, -0.120443, 0.000000 ) )
    pos.append( ( 0.143754, -0.120443, 0.000000 ) )
    pos.append( ( 0.183371, -0.120443, 0.000000 ) )
    pos.append( ( 0.192692, -0.234671, 0.000000 ) )
    pos.append( ( 0.146084, -0.234671, 0.000000 ) )
    pos.append( ( -0.408309, -0.234671, 0.000000 ) )
    pos.append( ( -0.426207, -0.234671, 0.000000 ) )
    pos.append( ( -0.499441, -0.348899, 0.000000 ) )
    pos.append( ( -0.499441, -0.477477, 0.000000 ) )
    pos.append( ( -0.499441, -0.498450, 0.000000 ) )
    pos.append( ( -0.471476, -0.498450, 0.000000 ) )
    pos.append( ( 0.329002, -0.493503, 0.000000 ) )
    pos.append( ( 0.355822, -0.493503, 0.000000 ) )
    pos.append( ( 0.493503, -0.329002, 0.000000 ) )
    pos.append( ( 0.493503, 0.000000, 0.000000 ) )
    pos.append( ( 0.351161, 0.093992, 0.000000 ) )
    pos.append( ( 0.316205, 0.093992, 0.000000 ) )
    pos.append( ( -0.151690, 0.093992, 0.000000 ) )
    pos.append( ( -0.181985, 0.093992, 0.000000 ) )
    pos.append( ( -0.181985, 0.225793, 0.000000 ) )
    pos.append( ( -0.154020, 0.225793, 0.000000 ) )
    pos.append( ( 0.417188, 0.225793, 0.000000 ) )
    pos.append( ( 0.426030, 0.225793, 0.000000 ) )
    
    new = mc.circle( ch = 0, d = 3, sections = 30 )[0]
    
    newCvs = mc.ls( new + '.cv[*]', fl = 1 )
    for i, cv in enumerate( newCvs ): mc.move( pos[i][0], pos[i][1], pos[i][2], new + '.cv[%d]' % i )
    
    shape.scale( new, scale )
    
    return new


def c( scale = [1, 1, 1] ):
    
    pos = []    
    pos.append( ( 0.494302, 0.495197, 0.000000 ) )
    pos.append( ( 0.370719, 0.495093, 0.000000 ) )
    pos.append( ( 0.247143, 0.495093, 0.000000 ) )
    pos.append( ( 0.000000, 0.495093, 0.000000 ) )
    pos.append( ( -0.247143, 0.495093, 0.000000 ) )
    pos.append( ( -0.370719, 0.495093, 0.000000 ) )
    pos.append( ( -0.494302, 0.373233, 0.000000 ) )
    pos.append( ( -0.494302, 0.266802, 0.000000 ) )
    pos.append( ( -0.494302, 0.000791, 0.000000 ) )
    pos.append( ( -0.494302, -0.265220, 0.000000 ) )
    pos.append( ( -0.494302, -0.371652, 0.000000 ) )
    pos.append( ( -0.370719, -0.493511, 0.000000 ) )
    pos.append( ( -0.247143, -0.493511, 0.000000 ) )
    pos.append( ( 0.000000, -0.493511, 0.000000 ) )
    pos.append( ( 0.247143, -0.493511, 0.000000 ) )
    pos.append( ( 0.370719, -0.493511, 0.000000 ) )
    pos.append( ( 0.494302, -0.493511, 0.000000 ) )
    pos.append( ( 0.494302, -0.340756, 0.000000 ) )
    pos.append( ( 0.494302, -0.184572, 0.000000 ) )
    pos.append( ( 0.370719, -0.184572, 0.000000 ) )
    pos.append( ( 0.252349, -0.184572, 0.000000 ) )
    pos.append( ( -0.065130, -0.184572, 0.000000 ) )
    pos.append( ( -0.185363, -0.184572, 0.000000 ) )
    pos.append( ( -0.188705, 0.000791, 0.000000 ) )
    pos.append( ( -0.185363, 0.186206, 0.000000 ) )
    pos.append( ( -0.065130, 0.186206, 0.000000 ) )
    pos.append( ( 0.252349, 0.186206, 0.000000 ) )
    pos.append( ( 0.370719, 0.186206, 0.000000 ) )
    pos.append( ( 0.494302, 0.186102, 0.000000 ) )
    pos.append( ( 0.494302, 0.328361, 0.000000 ) )
    
    new = mc.circle( ch = 0, d = 3, sections = 30 )[0]
    
    newCvs = mc.ls( new + '.cv[*]', fl = 1 )
    for i, cv in enumerate( newCvs ): mc.move( pos[i][0], pos[i][1], pos[i][2], new + '.cv[%d]' % i )
    
    shape.scale( new, scale )
    
    return new

def d( scale = [1, 1, 1] ):
    
    # outer curve
    pos = []
    pos.append( ( 0.312575, 0.453670, 0.000000 ) )
    pos.append( ( 0.050648, 0.499778, 0.000000 ) )
    pos.append( ( -0.459065, 0.499778, 0.000000 ) )
    pos.append( ( -0.459065, 0.441072, 0.000000 ) )
    pos.append( ( -0.473206, 0.000000, 0.000000 ) )
    pos.append( ( -0.459065, -0.441072, -0.000000 ) )
    pos.append( ( -0.459065, -0.500222, -0.000000 ) )
    pos.append( ( 0.050648, -0.500222, -0.000000 ) )
    pos.append( ( 0.312575, -0.453670, -0.000000 ) )
    pos.append( ( 0.504318, -0.261927, -0.000000 ) )
    pos.append( ( 0.540935, -0.000000, -0.000000 ) )
    pos.append( ( 0.504318, 0.261927, 0.000000 ) )
    
    new = mc.circle( ch = 0, d = 3, sections = 12 )[0]
    
    newCvs = mc.ls( new + '.cv[*]', fl = 1 )
    for i, cv in enumerate( newCvs ): mc.move( pos[i][0], pos[i][1], pos[i][2], new + '.cv[%d]' % i )
    
    # inner curve
    pos = []
    pos.append( ( 0.198522, 0.256126, 0.000000 ) )
    pos.append( ( 0.050648, 0.282157, 0.000000 ) )
    pos.append( ( -0.237118, 0.282157, 0.000000 ) )
    pos.append( ( -0.237118, 0.249013, 0.000000 ) )
    pos.append( ( -0.245101, 0.000000, 0.000000 ) )
    pos.append( ( -0.237118, -0.249013, -0.000000 ) )
    pos.append( ( -0.237118, -0.282407, -0.000000 ) )
    pos.append( ( 0.050648, -0.282407, -0.000000 ) )
    pos.append( ( 0.198522, -0.256126, -0.000000 ) )
    pos.append( ( 0.306774, -0.147874, -0.000000 ) )
    pos.append( ( 0.327446, -0.000000, -0.000000 ) )
    pos.append( ( 0.306774, 0.147874, 0.000000 ) )
    
    new2 = mc.circle( ch = 0, d = 3, sections = 12 )[0]
    
    new2Cvs = mc.ls( new2 + '.cv[*]', fl = 1 )
    for i, cv in enumerate( new2Cvs ): mc.move( pos[i][0], pos[i][1], pos[i][2], new2 + '.cv[%d]' % i )
    
    # parent inner shape under outer shape transform
    new2shape = mc.listRelatives( new2, s = True )[0]
    mc.parent( new2shape, new, r = True, s = True )
    mc.delete( new2 )
    
    shape.scale( new, scale )
    
    return new    
    
def sphere( scale = [1, 1, 1] ):
    
    pos = []    
    pos.append( ( 0.000000, 0.999990, 0.000000 ) )
    pos.append( ( 0.000000, 0.666660, -0.666660 ) )
    pos.append( ( 0.000000, 0.000000, -0.999990 ) )
    pos.append( ( 0.000000, -0.666660, -0.666660 ) )
    pos.append( ( 0.000000, -0.999990, 0.000000 ) )
    pos.append( ( 0.000000, -0.666660, 0.666660 ) )
    pos.append( ( 0.000000, 0.000000, 0.999990 ) )
    pos.append( ( 0.000000, 0.666660, 0.666660 ) )
    pos.append( ( 0.000000, 0.999990, 0.000000 ) )
    pos.append( ( 0.666660, 0.666660, 0.000000 ) )
    pos.append( ( 0.999990, 0.000000, 0.000000 ) )
    pos.append( ( 0.666660, -0.666660, 0.000000 ) )
    pos.append( ( 0.000000, -0.999990, 0.000000 ) )
    pos.append( ( -0.666660, -0.666660, 0.000000 ) )
    pos.append( ( -0.999990, 0.000000, 0.000000 ) )
    pos.append( ( -0.666660, 0.666660, 0.000000 ) )
    pos.append( ( 0.000000, 0.999990, 0.000000 ) )
    
    new = mc.curve( d = 1, p = pos )
    shape.scale( new, scale )
    
    return new

def key( scale = [1, 1, 1] ):
    
    """
    key shape looks like circle and stick, where stick points to zero position
    Default shape is oriented to +Z axis with length of 1.0 unit
    """
    
    pos = [
        [0.0, 0.0, 0.0],
        [0.00017381436326127666, 5.356139891764631e-18, 0.7448201414503202],
        [0.00036558406165623596, 7.667671701482482e-18, 0.7452030376423925],
        [-0.0013338675759171428, 7.420566124741423e-18, 0.7458407333627707],
        [-0.04164621059361427, 6.958551978512219e-18, 0.7567702661902211],
        [-0.10195406219935815, 5.439635262731316e-18, 0.7815760586332086],
        [-0.13875113220770655, 2.461944618224952e-33, 0.8704120441029555],
        [-0.09811186648138048, -6.007619162239751e-18, 0.9685239105843358],
        [-4.180842401769881e-17, -8.496056496811954e-18, 1.009163176310662],
        [0.0981118664813804, -6.007619162239754e-18, 0.968523910584336],
        [0.13875113220770655, -4.5632485179879335e-33, 0.8704120441029556],
        [0.09816339277610579, 6.000002135947121e-18, 0.7724245731011196],
        [0.03295260786724278, 7.660258748174157e-18, 0.7453105249791145],
        [0.0, 7.666541395935553e-18, 0.7452079215547514]
        ]
    
    new = mc.curve( d = 3, p = pos )
    shape.scale( new, scale )
    
    return new

def keyX( scale = [1, 1, 1] ):
    
    """
    key shape looks like circle and stick, where stick points to zero position
    Shape is oriented to +X axis with length of 1.0 unit
    """
    
    new = key( scale )
    mc.rotate( 0, 90, 0, new )
    mc.makeIdentity( new, a = True, r = True )
    
    return new

def keyY( scale = [1, 1, 1] ):
    
    """
    key shape looks like circle and stick, where stick points to zero position
    Shape is oriented to +Y axis with length of 1.0 unit
    """
    
    new = key( scale )
    mc.rotate( -90, 0, 0, new )
    mc.makeIdentity( new, a = True, r = True )
    
    return new


def orient( scale = [1, 1, 1] ):
    
    pos = []
    pos.append( ( -0.302001, 0.095983, -0.098766 ) )
    pos.append( ( -0.198457, 0.500783, -0.098766 ) )
    pos.append( ( -0.025885, 0.751175, -0.098766 ) )
    pos.append( ( -0.025885, 0.751175, -0.098766 ) )
    pos.append( ( -0.025885, 0.751175, -0.336638 ) )
    pos.append( ( -0.025885, 0.751175, -0.336638 ) )
    pos.append( ( 0.302001, 1.001567, 0.000000 ) )
    pos.append( ( 0.302001, 1.001567, 0.000000 ) )
    pos.append( ( -0.025885, 0.751175, 0.336638 ) )
    pos.append( ( -0.025885, 0.751175, 0.336638 ) )
    pos.append( ( -0.025885, 0.751175, 0.098766 ) )
    pos.append( ( -0.025885, 0.751175, 0.098766 ) )
    pos.append( ( -0.198457, 0.500783, 0.098766 ) )
    pos.append( ( -0.302001, 0.095983, 0.098766 ) )
    pos.append( ( -0.302001, 0.095983, 0.098766 ) )
    pos.append( ( -0.198457, 0.095983, 0.500783 ) )
    pos.append( ( -0.025885, 0.095983, 0.751175 ) )
    pos.append( ( -0.025885, 0.095983, 0.751175 ) )
    pos.append( ( -0.025885, 0.336638, 0.751175 ) )
    pos.append( ( -0.025885, 0.336638, 0.751175 ) )
    pos.append( ( 0.302001, 0.000000, 1.001567 ) )
    pos.append( ( 0.302001, 0.000000, 1.001567 ) )
    pos.append( ( -0.025885, -0.336638, 0.751175 ) )
    pos.append( ( -0.025885, -0.336638, 0.751175 ) )
    pos.append( ( -0.025886, -0.095983, 0.751175 ) )
    pos.append( ( -0.025886, -0.095983, 0.751175 ) )
    pos.append( ( -0.198457, -0.095983, 0.500783 ) )
    pos.append( ( -0.302001, -0.095983, 0.098766 ) )
    pos.append( ( -0.302001, -0.095983, 0.098766 ) )
    pos.append( ( -0.198457, -0.500783, 0.098766 ) )
    pos.append( ( -0.025886, -0.751175, 0.098766 ) )
    pos.append( ( -0.025886, -0.751175, 0.098766 ) )
    pos.append( ( -0.025886, -0.751175, 0.336638 ) )
    pos.append( ( -0.025886, -0.751175, 0.336638 ) )
    pos.append( ( 0.302001, -1.001567, 0.000000 ) )
    pos.append( ( 0.302001, -1.001567, 0.000000 ) )
    pos.append( ( -0.025886, -0.751175, -0.336638 ) )
    pos.append( ( -0.025886, -0.751175, -0.336638 ) )
    pos.append( ( -0.025886, -0.751175, -0.098766 ) )
    pos.append( ( -0.025886, -0.751175, -0.098766 ) )
    pos.append( ( -0.198457, -0.500783, -0.098766 ) )
    pos.append( ( -0.302001, -0.095983, -0.098766 ) )
    pos.append( ( -0.302001, -0.095983, -0.098766 ) )
    pos.append( ( -0.198457, -0.095983, -0.500783 ) )
    pos.append( ( -0.025886, -0.095983, -0.751175 ) )
    pos.append( ( -0.025886, -0.095983, -0.751175 ) )
    pos.append( ( -0.025885, -0.336638, -0.751175 ) )
    pos.append( ( -0.025885, -0.336638, -0.751175 ) )
    pos.append( ( 0.302001, 0.000000, -1.001567 ) )
    pos.append( ( 0.302001, 0.000000, -1.001567 ) )
    pos.append( ( -0.025885, 0.336638, -0.751175 ) )
    pos.append( ( -0.025885, 0.336638, -0.751175 ) )
    pos.append( ( -0.025885, 0.095983, -0.751175 ) )
    pos.append( ( -0.025885, 0.095983, -0.751175 ) )
    pos.append( ( -0.198457, 0.095983, -0.500783 ) )
    pos.append( ( -0.302001, 0.095983, -0.098766 ) )    

    new = mc.curve( d = 1, p = pos )    
    shape.scale( new, scale )
    
    return new
    

def aimbase( scale = [1, 1, 1] ):
    
    pos = []
    pos.append( ( 0.830818, 0.000000, 0.000000 ) )
    pos.append( ( 0.830818, 0.000000, -0.707107 ) )
    pos.append( ( 0.000000, 0.000000, -0.707107 ) )
    pos.append( ( -0.830818, 0.000000, -0.707107 ) )
    pos.append( ( -0.830818, 0.000000, -0.000000 ) )
    pos.append( ( -0.830818, 0.000000, 0.707107 ) )
    pos.append( ( 0.000000, 0.000000, 1.192222 ) )
    pos.append( ( 0.830818, 0.000000, 0.707107 ) )
    pos.append( ( 0.830818, 0.000000, 0.000000 ) )
    
    new = mc.curve( d = 1, p = pos )    
    shape.scale( new, scale )
    
    return new

def arrow( scale = [1, 1, 1] ):
    
    pos = []
    pos.append( ( 0.000000, 0.000000, 0.000000 ) )
    pos.append( ( 0.000000, 0.621418, 0.000000 ) )
    pos.append( ( -0.153696, 0.621418, 0.000000 ) )
    pos.append( ( 0.000000, 1.000000, 0.000000 ) )
    pos.append( ( 0.153696, 0.621418, 0.000000 ) )
    pos.append( ( 0.000000, 0.621418, 0.000000 ) )
    pos.append( ( 0.000000, 0.621418, 0.153696 ) )
    pos.append( ( 0.000000, 1.000000, 0.000000 ) )
    pos.append( ( 0.000000, 0.621418, -0.153696 ) )
    pos.append( ( 0.000000, 0.621418, 0.000000 ) )
    
    new = mc.curve( d = 1, p = pos )
    shape.scale( new, scale )
    
    return new

def starSimple( scale = [1, 1, 1] ):
    
    new = mc.circle( nr = [1, 0, 0], ch = 0, r = 1.0, d = 3 )[0]
    cvs = mc.ls( new + '.cv[*]', fl = True )
    
    pos = []
    pos.append( ( 0.000000, 0.091018, -0.091018 ) )
    pos.append( ( -0.000000, 1.322251, 0.000000 ) )
    pos.append( ( -0.000000, 0.091018, 0.091018 ) )
    pos.append( ( -0.000000, 0.000000, 1.322251 ) )
    pos.append( ( -0.000000, -0.091018, 0.091018 ) )
    pos.append( ( -0.000000, -1.322251, 0.000000 ) )
    pos.append( ( 0.000000, -0.091018, -0.091018 ) )
    pos.append( ( 0.000000, -0.000000, -1.322251 ) )
    
    for i in range( len( cvs ) ):
        
        mc.xform( cvs[i], t = pos[i], ws = True )
    
    shape.scale( new, scale )
    
    return new
    
def cross( scale = [1, 1, 1] ):
    
    pos = []
    pos.append( ( -0.333000, 0.000000, -0.333000 ) )
    pos.append( ( -0.333000, 0.000000, -0.999000 ) )
    pos.append( ( 0.333000, 0.000000, -0.999000 ) )
    pos.append( ( 0.333000, 0.000000, -0.333000 ) )
    pos.append( ( 0.999000, 0.000000, -0.333000 ) )
    pos.append( ( 0.999000, 0.000000, 0.333000 ) )
    pos.append( ( 0.333000, 0.000000, 0.333000 ) )
    pos.append( ( 0.333000, 0.000000, 0.999000 ) )
    pos.append( ( -0.333000, 0.000000, 0.999000 ) )
    pos.append( ( -0.333000, 0.000000, 0.333000 ) )
    pos.append( ( -0.999000, 0.000000, 0.333000 ) )
    pos.append( ( -0.999000, 0.000000, -0.333000 ) )
    pos.append( ( -0.333000, 0.000000, -0.333000 ) )
    
    new = mc.curve( d = 1, p = pos )
    shape.scale( new, scale )
    
    return new

def line( normal = [1, 0, 0], scale = [1, 1, 1] ):
    
    pos = []
    pos.append( ( 0, 0, 0 ) )
    pos.append( normal )
    
    new = mc.curve( d = 1, p = pos )
    shape.scale( new, scale )
    
    return new

def eye( scale = [1, 1, 1] ):
    
    pos = []
    pos.append( ( 0.000000, 0.059884, -0.783612 ) )
    pos.append( ( 0.000000, 0.881595, -0.000000 ) )
    pos.append( ( -0.000000, 0.059884, 0.783612 ) )
    pos.append( ( -0.000000, 0.000000, 1.108194 ) )
    pos.append( ( -0.000000, -0.059884, 0.783612 ) )
    pos.append( ( -0.000000, -0.881595, 0.000000 ) )
    pos.append( ( 0.000000, -0.059884, -0.783612 ) )
    pos.append( ( 0.000000, -0.000000, -1.108194 ) )
    
    new = mc.circle( normal = [1, 0, 0] )[0]
    cvs = mc.ls( new + '.cv[*]', fl = True )
    
    for cv, p in zip( cvs, pos ):
        
        mc.move( p[0], p[1], p[2], cv )
    
    shape.scale( new, scale )
    
    return new

def eyeY( scale = [1, 1, 1] ):
    
    """
    eye Z version
    """
    
    new = eye( scale )
    mc.rotate( -90, 0, 90, new )
    mc.makeIdentity( new, a = True, r = True )
    
    return new

def eyeZ( scale = [1, 1, 1] ):
    
    """
    eye Y version
    """
    
    new = eye( scale )
    mc.rotate( 0, 90, 0, new )
    mc.makeIdentity( new, a = True, r = True )
        
    return new




