'''
numbers in rigit.utils
@category Rigging @subcategory Utils
@tags numbers index indeces math
@author jakub
'''

import maya.cmds as mc


def getMissingFromSparseIntArray( sparseArray = None ):
    
    '''
    return missing numbers from sparse integer array,
    useful for finding available indeces in sparse index array
    
    @param sparseArray: array of integer numbers which might be sparse
    @type sparseArray: list( int )
    @return: list( int )
    '''
    
    # make nonsparse array starting at 0
    sparseArray.sort()
    maxValue = sparseArray[-1]
    nonsparseArray = range( maxValue + 1 )
    
    missingIndeces = [ item for item in nonsparseArray if not item in sparseArray ]
    
    return missingIndeces
    
    
def getNextAvailableIndex( indexArray ):
    
    '''
    get next available index, which works for sparse arrays
    First return missing indeces in sparse gaps, then appending numbers
    
    @param indexArray: index array
    @type indexArray: list( int )
    @return: list( int )
    '''
    
    if not indexArray or not len( indexArray ):
        
        return 0
    
    missingIndeces = getMissingFromSparseIntArray( sparseArray = indexArray )
    
    if missingIndeces:
        
        nextIndex = missingIndeces[0]
    
    else:
        
        indexArray.sort()
        nextIndex = indexArray[-1] + 1
    
    return nextIndex


        
        
    
    
    


