'''
transform module at rigit.utils
@category Rigging @subcategory Utils
@tags distance measure transform
@author jakub
'''

import math
import types

import maya.cmds as mc

from . import vector

    
def measureDistanceBetween2Points( pointA, pointB ):
    
    '''
    @param objectA: first point
    @type objectA: list(3 floats)
    @param objectB: second point
    @type objectB: list(3 floats)
    @return: float, distance between given points in same space
    '''
    
    vectA = vector.makeMVector( [ pointA[0], pointA[1], pointA[2] ] )
    vectB = vector.makeMVector( [ pointB[0], pointB[1], pointB[2] ] )
    pointDif = vectB - vectA
    
    return pointDif.length()
    

def measureDistanceBetweenMultiplePositions( positionList ):
    
    '''
    return sum of distances between chain of positions
    This depends on order of objects as they were passed to function,
    ideal for measuring length of geometry CVs perimeter
    
    @param objectList: list of transform names
    @type objectList: list(str)
    @return: float, distance sum
    '''
    
    distancesum = 0.0
    
    for i in range( 1, len( positionList ) ):
        
        distancesum += measureDistanceBetween2Points( positionList[i - 1], positionList[i] )
    
    return distancesum
