'''
connect at rigit.utils
@category Rigging @subcategory Utils
@tags connect message
@author: jakub
'''


import maya.cmds as mc

from . import numbers


def message( sourceObj, destObj, sourceMsgName = 'msg', destMsgName = 'msg' ):
    
    '''
    create a message connection using multi-attribute so destination can have more messages connected
    
    @param sourceObj: source object name
    @type sourceObj: str
    @param destObj: destination object name
    @type destObj: str
    @param sourceMsgName: source message attribute name
    @type sourceMsgName: str
    @param destMsgName: destination message attribute name
    @type destMsgName: str
    @return: None
    '''
    
    if not mc.objExists( sourceObj + '.' + sourceMsgName ):
        
        mc.addAttr( sourceObj, ln = sourceMsgName, at = 'message' )
    
    if not mc.objExists( destObj + '.' + destMsgName ):
        
        mc.addAttr( destObj, ln = destMsgName, at = 'message', multi = 1 )
    
    # find the next available index
    
    destMessageInds = mc.getAttr( destObj + '.' + destMsgName, mi = 1 )
    destIndex = 0
    if destMessageInds: destIndex = numbers.getNextAvailableIndex( destMessageInds )
    
    # connect message attributes
    
    srcPlug = sourceObj + '.' + sourceMsgName
    destPlug = destObj + '.' + destMsgName + '[{}]'.format(destIndex)
    mc.connectAttr( srcPlug, destPlug )

def disconnect( plug, source = True, destinations = False ):
    
    '''
    disconnect connection to the plug
    
    @param plug: name of plug to disconnect, for example 'petrolPipe20_jnt.sx'
    @type type: str
    @param source: break source of this plug
    @type source: bool
    @param destinations: break connections to destinations from this plug
    @type destinations: bool
    @return: list( list, list ), first list contains source connections, second list contains destination connections
    '''
    
    results = [ [], [] ]
    
    if source:
        
        cons = mc.listConnections( plug, s = 1, d = 0, p = 1 )

        if cons:

            for con in cons:

                mc.disconnectAttr( con, plug )

        results[0] = cons
    
    if destinations:
        
        dests = mc.listConnections( plug, s = 0, d = 1, p = 1 )

        if dests:

            for dest in dests:

                mc.disconnectAttr( plug, dest )

        results[1] = dests
    
    return results
