'''
deformer at rigit.utils
@category Rigging @subcategory Utils
@tags deformer
@author: jakub

general utilities to support work with deformers
'''

import maya.cmds as mc


def getConnectedShapes( deformernode, skipOrigShapes = True, returnOnlyGeometry = True, returnShapeTypes = [ 'mesh', 'nurbsSurface', 'nurbsCurve', 'lattice' ] ):
    
    '''
    get downstream ("product") shape from given deformer, more options to be added to get OrigShape etc.
    
    @param deformernode: deformer node
    @type deformernode: str
    @return: str, if shape was found otherwise None
    @type skipOrigShapes: skip shape if it is "Orig" shape, created usualy by deformer
    @param skipOrigShapes: bool
    @param returnOnlyGeometry: return only geometry, useful if deformer would have other shape types connected, like clusterHandle
    @type returnOnlyGeometry: bool
    @return: list(str), list with names of shapes, if no shapes found, return empty list
    '''
    
    deformerfuture = mc.listHistory( deformernode, future = 1 )
    deformershapes = mc.ls( deformerfuture )
    
    if deformershapes:
        
        # filter orig shapes
        
        filteredShapes = []
        
        for defshape in deformershapes:
            
            canBeAdded = True
            
            if skipOrigShapes:
                
                canBeAdded = True
                intermedState = 0
                
                if mc.objExists( defshape + '.intermediateObject' ):
                    
                    intermedState = mc.getAttr( defshape + '.intermediateObject' )
                    
                if intermedState == 1:
                    
                    canBeAdded = False
            
            if returnOnlyGeometry:
                
                defshapeNodeType = mc.nodeType( defshape )
                
                if not defshapeNodeType in returnShapeTypes:
                    
                    canBeAdded = False
            
            if canBeAdded:
                
                filteredShapes.append( defshape )
        
        return filteredShapes
    
    return []    


