'''
joint in rigit.utils
@category Rigging @subcategory Utils
@tags joint skeleton
'''

import maya.cmds as mc


def makeSingleJoint( prefix = 'new', refObject = None, radius = 1.0, refJointRadiusMulti = 0.0, colorIdx = -1, parentObj = None, freezeRotation = True, zeroJointOrient = False ):
    
    """
    make single joint with option to use reference object and parent
    
    @param prefix: str, prefix for naming new joint
    @param refObject: str, reference object for joint transform
    @param radius: float, radius for new joint
    @param refJointRadiusMulti: float, get radius from multiple of refObject radius if this is joint and multi value other then zero  
    @param colorIdx: int, color index for new joint based on Maya color command -userDefined range
    @param parentObj: str, optional, name of object for parenting new joint
    @param freezeRotation: bool, freeze rotation of new joint so it will be zeroed out and converted to joint orient
    @param zeroJointOrient: bool, zero out jointOrient values
    @return: str, name of new joint
    """
    
    # make joint
    jnt = mc.createNode( 'joint', n = prefix + '_jnt' )
        
    # set joint attributes
    jntRadius = radius
    
    if mc.nodeType( refObject ) == 'joint' and not refJointRadiusMulti == 0:
        
        jntRadius = mc.getAttr( refObject + '.radius' ) * refJointRadiusMulti
    
    mc.setAttr( jnt + '.radius', jntRadius )
    
    if colorIdx != -1:
        mc.color( jnt, ud = colorIdx )      
    
    # parent joint
    if parentObj:
        
        jnt = mc.parent( jnt, parentObj )[0]

    # perform zero JointOrient before constraint rotation
    if zeroJointOrient:
        
        mc.setAttr( jnt + '.jo', 0, 0, 0 )

    # move joint
    if refObject:
        
        mc.delete( mc.parentConstraint( refObject, jnt ) )
    
    # freeze rotation
    if freezeRotation:
        
        mc.makeIdentity( jnt, a = True, r = True )
    
    
    return jnt

